@@ -11,6 +11,8 @@ class Matchup(object):
         '''Fetch info for matchup'''
         self.home_team = self.data['home']['teamId']
         self.home_score = self.data['home']['totalPoints']
+        self.matchup_type = self.data.get('playoffTierType', 'NONE')
+        self.is_playoff = self.matchup_type != 'None'
 
         # For Leagues with bye weeks
         self.away_team = 0
